<?php

namespace Boomee\GoodToKnow\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Boomee\GoodToKnow\Interfaces\NewsRepositoryInterface;

class NewsPublicController extends BaseController
{
    // use NewsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Boomee\News\Interfaces\NewsRepositoryInterface $news
     *
     * @return type
     */
    public function __construct(NewsRepositoryInterface $news)
    {
        $this->repository = $news;
        parent::__construct();
    }

    /**
     * Show news's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $news = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('good_to__know::news.names'))
            ->view('good_to__know::public.news.index')
            ->data(compact('news'))
            ->output();
    }


    /**
     * Show news.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $news = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($news->name . trans('good_to__know::news.name'))
            ->view('good_to__know::public.news.show')
            ->data(compact('news'))
            ->output();
    }

}
