<?php

namespace Boomee\GoodToKnow\Providers;

use Illuminate\Support\ServiceProvider;

class GoodToKnowServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'good_to__know');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'good_to__know');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerGoodToKnow();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerGoodToKnow()
    {
        $this->app->bind('good_to__know', function($app) {
            return new GoodToKnow($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('GoodToKnow', 'Lavalite\GoodToKnow\Facades\GoodToKnow');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('boomee.good_to__know', function ($app) {
            return $this->app->make('Boomee\GoodToKnow\GoodToKnow');
        });

                // Bind News to repository
        $this->app->bind(
            'Boomee\GoodToKnow\Interfaces\NewsRepositoryInterface',
            \Boomee\GoodToKnow\Repositories\Eloquent\NewsRepository::class
        );

        $this->app->register(\Boomee\GoodToKnow\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Boomee\GoodToKnow\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and good_to__know's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'boomee.good_to__know'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeGoodToKnow::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['boomee.good_to__know'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('boomee/good_to__know.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/good_to__know')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/good_to__know')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
